Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1560)

Unified Diff: ash/common/system/chromeos/network/network_list.h

Issue 2698473007: Convert path usage in NetworkListViewBase subclasses to use guids. (Closed)
Patch Set: Tweak NetworkPortalNotificationControllerTest to create GUIDs for new NetworkStates. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/common/system/chromeos/network/network_list.h
diff --git a/ash/common/system/chromeos/network/network_list.h b/ash/common/system/chromeos/network/network_list.h
index cf9dc3011450e756abef0ec5e8009e5e143d4343..2e4090b13290f37fac515e8c422101fa5889bc02 100644
--- a/ash/common/system/chromeos/network/network_list.h
+++ b/ash/common/system/chromeos/network/network_list.h
@@ -37,8 +37,7 @@ class NetworkListView : public NetworkListViewBase,
// NetworkListViewBase:
void Update() override;
- bool IsNetworkEntry(views::View* view,
- std::string* service_path) const override;
+ bool IsNetworkEntry(views::View* view, std::string* guid) const override;
private:
void UpdateNetworks(
@@ -46,8 +45,8 @@ class NetworkListView : public NetworkListViewBase,
void UpdateNetworkIcons();
void UpdateNetworkListInternal();
void HandleRelayout();
- bool UpdateNetworkListEntries(std::set<std::string>* new_service_paths);
- bool UpdateNetworkChildren(std::set<std::string>* new_service_paths,
+ bool UpdateNetworkListEntries(std::set<std::string>* new_guids);
+ bool UpdateNetworkChildren(std::set<std::string>* new_guids,
int* child_index,
bool highlighted);
bool UpdateNetworkChild(int index, const NetworkInfo* info);
@@ -68,9 +67,9 @@ class NetworkListView : public NetworkListViewBase,
typedef std::map<views::View*, std::string> NetworkMap;
NetworkMap network_map_;
- // A map of network service paths to their view.
- typedef std::map<std::string, views::View*> ServicePathMap;
- ServicePathMap service_path_map_;
+ // A map of network guids to their view.
+ typedef std::map<std::string, views::View*> NetworkGuidMap;
+ NetworkGuidMap network_guid_map_;
DISALLOW_COPY_AND_ASSIGN(NetworkListView);
};
« no previous file with comments | « ash/common/system/chromeos/network/network_info.cc ('k') | ash/common/system/chromeos/network/network_list.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698